/* 
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */

class MenuScene extends Phaser.Scene {
    
    constructor() {
      //https://www.w3schools.com/jsref/jsref_class_super.asp  
      super({ key: 'menuScene' });
    }    
    
    create() 
    {
        this.levelGameButton1 = this.make.text({
          x: 200,
          y: 200,
          text: 'LEVEL 1',
          style: {
            font: '30px monospace',
            fill: '#ffffff'
          }
        });         

        this.levelGameButton2 = this.make.text({
          x: 200,
          y: 300,
          text: 'LEVEL 2',
          style: {
            font: '30px monospace',
            fill: '#ffffff'
          }
        }); 
        
        //https://www.w3schools.com/js/js_arrow_function.asp
        this.levelGameButton1.setInteractive();
        this.levelGameButton1.on('pointerdown', () => this.clickLevelButton1());
        
        this.levelGameButton2.setInteractive();
        this.levelGameButton2.on('pointerdown', () => this.clickLevelButton2());
    }
    
    clickLevelButton1()
    {
        this.scene.start('gameScene', {level: 1});
        
    }
        
    clickLevelButton2() {
        //alert("asd")
        this.scene.start('gameScene', {level: 2});
    }  
}

class GameScene extends Phaser.Scene {
       
    constructor() {
      super({ key: 'gameScene' });
      this.currentLevel = 1;
    }    
      
    preload () {
        
        this.load.spritesheet('robot', 'assets/lego.png',
            { frameWidth: 37, frameHeight: 48 } ); 

        this.load.spritesheet('items', 'assets/items.png',
            { frameWidth: 32, frameHeight: 32 } ); 

        this.load.image('tiles', 'assets/map_tiles.png');
        
        this.load.tilemapTiledJSON('json_map_1', 'assets/json_map_1.json');
        this.load.tilemapTiledJSON('json_map_2', 'assets/json_map_2.json'); 
        
        this.load.image('bomb', 'assets/bomb.png');        
        
    }
    
    create (data)  {
        
        console.log(data.level);
        this.lvl = 'json_map_' + data.level;
        console.log(this.lvl);
        this.map = this.make.tilemap({ key: this.lvl });
        //'map_tiles' - name of the tilesets in json_map.json
        //'tiles' - name of the image in load.images()
        this.tiles = this.map.addTilesetImage('map_tiles','tiles');

        this.backgroundLayer = this.map.createLayer('background', this.tiles, 0, 0);
        this.collisionLayer = this.map.createLayer('collision', this.tiles, 0, 0).setVisible(false);
        this.collisionLayer.setCollisionByExclusion([ -1 ]);

        this.items = this.physics.add.sprite(100, 100, 'items', 0);
        this.items.setBounce(0.1);

        this.player = this.physics.add.sprite(100, 450, 'robot');
        this.player.setBounce(0.1);

        this.bombs = this.physics.add.group();

        this.physics.add.collider(this.player, this.collisionLayer);
        this.physics.add.overlap(this.player, this.backgroundLayer);
        this.physics.add.collider(this.bombs, this.collisionLayer); 
        
        
        this.cursors = this.input.keyboard.createCursorKeys();
        
        this.physics.add.overlap(this.player, this.items, this.collisionHandler, null, this);
        
        this.anims.create({
            key: 'run',
            frames: this.anims.generateFrameNumbers('robot', { start: 0, end: 15 }),
            frameRate: 20,
            repeat: -1
        });        
        
        
    }
    
    collisionHandler(player, item)
    {
        //this.currentLevel + 1
        //alert(this.currentLevel);
        this.scene.start("gameScene", {level: 2});        
    }
    
    update() {
        
        // Horizontal movement
        if (this.cursors.left.isDown)
        {
            this.player.body.setVelocityX(-250);
            this.player.angle = 90;
            this.player.anims.play('run', true); 
        }
        else if (this.cursors.right.isDown)
        {
            this.player.body.setVelocityX(250);
            this.player.angle = 270;
            this.player.anims.play('run', true); 
        }
        else
        {
            this.player.body.setVelocityX(0);
        }

        // Vertical movement
        if (this.cursors.up.isDown)
        {
            this.player.body.setVelocityY(-250);
            this.player.angle = 180;
            this.player.anims.play('run', true); 
        }
        else if (this.cursors.down.isDown)
        {
            this.player.body.setVelocityY(250);
            this.player.anims.play('run', true); 
            this.player.angle = 0;
        }
        else
        {
           this.player.body.setVelocityY(0);
        }        
        
    }
    
    
}

var config = {
    type: Phaser.AUTO,
    width: 1920,
    height: 1080,
    physics: {
        default: 'arcade',
        arcade: {
            gravity: { y: 0 },           
            debug: false
        }
    },
    debug: true
};




var game = new Phaser.Game(config);

var menuScene = new MenuScene();
var gameScene = new GameScene();
game.scene.add('menuScene', menuScene);
game.scene.add('gameScene', gameScene);
game.scene.start('menuScene');
